/***************************************************************************
                          amarokInterface.h
            this is the abstract class to access Amarok from
                             -------------------
    begin                : Tue Dec  2 23:54:53 CET 2003
    copyright            : (c) 2003 by Thomas Capricelli
    adapted from juk* (C) 2001-2002 by Stefan Gehn (sgehn@gmx.net)
    email                : orzel@freehackers.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef AMAROKINTERFACE_H
#define AMAROKINTERFACE_H

#include "playerInterface.h"

#include <kapplication.h>
#include <dcopclient.h>

#include <qtimer.h>

class AmarokInterface : public PlayerInterface
{
   Q_OBJECT
   public:
      AmarokInterface();
      ~AmarokInterface();

/* PlayerInterface...
      virtual void updateSlider()=0; // gets called on timer-timeout
      virtual void sliderStartDrag()=0;
      virtual void sliderStopDrag()=0;
      virtual void jumpToTime( int msec )=0;
      virtual void play()=0;
      virtual void pause()=0;
      virtual void stop()=0;
      virtual void next()=0;
      virtual void prev()=0;
      virtual void dragEnterEvent(QDragEnterEvent* event)=0;
      virtual void dropEvent(QDropEvent* event)=0;
      virtual const QString getTrackTitle() const=0;
   signals:
      void newSliderPosition ( int, int );
*/
   public slots:
      void updateSlider();
      void sliderStartDrag();
      void sliderStopDrag();
      void jumpToTime( int sec );
      void play();
      void pause();
      void stop();
      void next();
      void prev();
      void dragEnterEvent(QDragEnterEvent* event);
      void dropEvent(QDropEvent* event);
      const QString getTrackTitle() const;
      void appRegistered ( const QCString &appId );
      void appRemoved ( const QCString &appId );

      void myInit(void);

   signals:
      void newSliderPosition ( int, int );
      void playerStarted(void);
      void playerStopped(void);

   private:
      QTimer *mAmarokTimer;
      int mTimerValue;
      QCString mAppId;

      /**
       * Tries to find a DCOP registered instance of AmaroK
       * Stores the name of the first found instance in appId
       * @returns true is instance is found, false otherwise
       */
      bool findRunningAmarok();
};
#endif
