// -*- Mode: C++; c-basic-offset: 2; indent-tabs-mode: nil; tab-width: 8; -*-

/***************************************************************************
    norsswidget.cpp
    Marcus Camen  <mcamen@mcamen.de>
***************************************************************************/

/*
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  Boston, MA 02111-1307, USA.
*/

#include <qlayout.h>
#include <qsizepolicy.h>
#include <dcopref.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kpushbutton.h>
#include <kdebug.h>
#include "newrsssourcedlg.h"
#include "sidebarsettings.h"
#include "norsswidget.h"


namespace KSB_News {

  NoRSSWidget::NoRSSWidget(QWidget *parent, const char *name) : QWidget(parent, name) {
    // TODO: be more verbose and add a button for calling
    //       NSStackTabWidget::slotNew()

    QVBoxLayout *topLayout = new QVBoxLayout(this);

    topLayout->addStretch();

    m_newDlg = new NewRssSourceDlg( this );
    KPushButton *btn = new KPushButton( i18n("A&dd"), this );
    btn->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Minimum );
    connect( btn, SIGNAL( clicked() ), this, SLOT( slotBtnClicked() ) );
    topLayout->addWidget( btn, 0, Qt::AlignHCenter );

    topLayout->addStretch();
  }


  void NoRSSWidget::slotBtnClicked() {
    m_newDlg->show();
    connect(m_newDlg, SIGNAL(okClicked()), this, SLOT(slotNewOkClicked()));
  }


  void NoRSSWidget::slotNewOkClicked() {
    // TODO: wrong URI error handling

    // save configuration to disk
    kdDebug(90140) << "norsswidget: " << m_newDlg->getText() << endl;
    SidebarSettings::setSources(QStringList( m_newDlg->getText() ));
    SidebarSettings::writeConfig();

    // tell the DCOP service to add then new RSS source
    DCOPRef rss_document("rssservice", "RSSService");
    rss_document.call("add", m_newDlg->getText());
  }

} // namespace KSB_News

#include "norsswidget.moc"
