/***************************************************************************
                          nsstacktabwidget.cpp  -  description
                             -------------------
    begin                : Sat 07.09.2002
    copyright            : (C) 2002 by Marcus Camen
    email                : mcamen@mcamen.de
 ***************************************************************************/

/*
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#include <qpushbutton.h>
#include <qlayout.h>
#include <qcursor.h>
#include <qtoolbox.h>
#include <kdebug.h>
#include <kaboutapplication.h>
#include <kpopupmenu.h>
#include <kiconloader.h>
#include "newrsssourcedlg.h"
#include "nsstacktabwidget.h"


NSStackTabWidget::NSStackTabWidget(QWidget *parent, const char *name, QPixmap appIcon) :  QWidget(parent, name)
  {
    layout = new QVBoxLayout(this);

    // ToolBox
    m_toolbox = new QToolBox(this);
    layout->addWidget(m_toolbox);

    // about dialog
    m_aboutdata = new KAboutData("newsapplet", I18N_NOOP("RSS"),
                                 "0.1", I18N_NOOP("Sidebar News Applet"),
                                 KAboutData::License_LGPL, 0, 0, 0, "mcamen@mcamen.de");
    m_aboutdata->addAuthor("Marcus Camen", I18N_NOOP("Maintainer"), "mcamen@mcamen.de");
    m_aboutdata->addAuthor("Frerich Raabe", I18N_NOOP("librss"), "raabe@kde.org");
    m_aboutdata->addAuthor("Ian Reinhart Geiser", I18N_NOOP("rssservice"), "geiseri@kde.org");
    m_aboutdata->addAuthor("Joseph Wenninger", I18N_NOOP("Idea and former maintainer"), "jowenn@kde.org");
    m_about = new KAboutApplication(m_aboutdata, this);

    // popup menu
    popup = new KPopupMenu(this);
    popup->insertItem(SmallIcon("new"), i18n("&New"), this, SLOT(slotNew()));
    popup->insertItem(SmallIcon("reload"), i18n("&Reload"), this, SLOT(slotRefresh()));
    popup->insertItem(SmallIcon("fileclose"), i18n("&Close"), this, SLOT(slotClose()));
    popup->insertItem(appIcon, i18n("&About"), this, SLOT(slotShowAbout()));

    // redirect signals
    connect(m_toolbox, SIGNAL(currentChanged(int)), this, SLOT(slotCurrentChanged(int)));
    m_toolbox->installEventFilter(this);
  }


void NSStackTabWidget::addStackTab(NSPanel *nsp, QWidget *page)
  {
    m_toolbox->addItem(page, nsp->getTitle());
    m_toolbox->setItemToolTip(m_toolbox->indexOf(page), nsp->getTitle());
    nspanels.insert(page, nsp);
  }



void NSStackTabWidget::delStackTab(NSPanel *nsp)
  {
    m_toolbox->removeItem(m_toolbox->currentItem());
    nspanels.take(m_toolbox->currentItem());
  }



void NSStackTabWidget::updatePixmap(NSPanel *nsp)
  {
    QPixmap pix = nsp->getPixmap();
    QWidget *currentPage;

    QPtrDictIterator<NSPanel> it(nspanels);
    for (; it.current(); ++it) {
      NSPanel *currentNsp = (NSPanel *)it.current();
      if (currentNsp == nsp)
        currentPage = (QWidget *)it.currentKey();
    }

    m_toolbox->setItemIconSet(m_toolbox->currentIndex(), QIconSet(pix));
  }


bool NSStackTabWidget::eventFilter(QObject *obj, QEvent *ev)
  {
    //kdDebug(90140) << "NSStackTabWidget::eventFilter: " << obj << endl;

    if (ev->type() == QEvent::MouseButtonPress && ((QMouseEvent *)ev)->button() == QMouseEvent::RightButton)
      {
        //kdDebug(90140) << "NSStackTabWidget::eventFilter RightButton" << endl;
        popup->exec(QCursor::pos());
        return true;
      }
    return false;   // pass through event
  }


void NSStackTabWidget::slotNew()
  {
    m_newDlg = new NewRssSourceDlg(this);
    m_newDlg->show();
    connect(m_newDlg, SIGNAL(okClicked()), this, SLOT(slot_newOkClicked()));
  }


void NSStackTabWidget::slot_newOkClicked()
  {
    // TODO: error handling
    kdDebug(90140) << "NSStackTabWidget::slot_newOkClicked: " << m_newDlg->getText() << endl;
    DCOPRef rss_document("rssservice", "RSSService");
    rss_document.call("add", m_newDlg->getText());
  }


void NSStackTabWidget::slotShowAbout()
  {
    m_about->show();
  }


void NSStackTabWidget::slotRefresh()
  {
    slotCurrentChanged(m_toolbox->currentIndex());
  }


void NSStackTabWidget::slotClose()
  {
    kdDebug(90140) << "NSStackTabWidget::slotClose" << endl;

    NSPanel *nsp = nspanels.find(m_toolbox->currentItem());

    if (! nsp)
      {
        kdWarning() << "NSStackTabWidget::slotClose: no appendant NSPanel found" << endl;
        return;
      } else {
        // TODO: check, if rssservice is available
        DCOPRef rss_document("rssservice", "RSSService");
        rss_document.call("remove", nsp->getKey());
      }
  }


void NSStackTabWidget::slotCurrentChanged(int index)
  {
     kdDebug(90140) << "NSStackTabWidget::slotCurrentChanged" << endl;

     NSPanel *nsp = nspanels.find(m_toolbox->item(index));
     if (nsp) {  // TODO: sometimes we have nsp == NULL, why?
       nsp->refresh();
     }
  }


bool NSStackTabWidget::isEmpty() const
  {
    return !m_toolbox->count();
  }

#include "nsstacktabwidget.moc"
